@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Class::Component 0.16;
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 use Carp;
 use Encode;
@@ -180,7 +180,7 @@ sub _make_response {
     my $self = shift;
     my %args = validate(
         @_ => +{
-            c       => { isa  => 'HTTP::Engine::Context', },
+            c       => { isa  => 'HTTP::Engine::Compat::Context', },
             user_id => { type => SCALAR },
         }
     );
